@@ -9,8 +9,6 @@ from multiprocessing import Pool
 from os import remove
 import numpy as np
 import tables
-from scipy.ndimage.interpolation import zoom  # upscale p0 from some sample
-from sklearn.decomposition import PCA
 from tqdm import tqdm
 
 from ..Tools import get_memory_use
@@ -273,6 +271,8 @@ def rho_models_to_kwargs(rtfo, rho_model, wvls, logger):
     :param rho_model: dict with opts
     :return: list of instances of rho to ry and vice versa
     """
+    from sklearn.decomposition import PCA  # import here to avoid static TLS ImportError
+
     logger.info("Include rho model of type: %s" % rho_model["type"])
     if rho_model["type"] == "pca":
 
@@ -475,6 +475,9 @@ def opt(i1, i2, fo="flags", raise_flag=True, wvl_idxs=slice(None), **opt_args):
 def sample_optimization_and_upscale_results(data, p0):
     global logger, settings
     if settings["guess_dims_upscale"] is not None or settings["guess_dims_upscale"] == []:
+        # import here to avoid static TLS ImportError
+        from scipy.ndimage.interpolation import zoom  # upscale p0 from some sample
+
         default_value = -999.0
         flag = settings["fo_instances"][settings["default_fo"]]["flag"]
         logger.info("Use sample points estimates to upscale estimate for whole image.")
