@@ -7,12 +7,9 @@ import tables
 import importlib
 from numba import jit
 from time import time, sleep
-from scipy.ndimage.filters import gaussian_filter1d
-from scipy.ndimage import zoom
 from multiprocessing import Pool
 from multiprocessing import cpu_count
 from itertools import product
-from scipy.optimize import minimize
 import pyprind
 from tqdm import tqdm
 
@@ -168,6 +165,8 @@ def opt(self, y_rfl, pt0, rho_0=[{"method": "const", "value": 0.1},
         ssei=None, ssai=None, instrument_error_model=None, compute_errors=True, sc_oe_thres=0.01,
         optimization=True, se_jj_sa=__se_jj_sa_jit__, rho_fg=None
         ):
+    from scipy.ndimage.filters import gaussian_filter1d  # import here to avoid static TLS ImportError
+
     t0 = time()
 
     if ssei is None:
@@ -1373,6 +1372,8 @@ def __min__(ii, debug=False, only_success=False):
     :param only_success:
     :return:
     """
+    from scipy.optimize import minimize  # import here to avoid static TLS ImportError
+
     i1, i2 = ii
     if __data__[i1, i2, 0] == 0.0:
         return
@@ -1413,6 +1414,7 @@ def __min__(ii, debug=False, only_success=False):
 
 
 def __rezoom__(res, data_shape, order=3):
+    from scipy.ndimage import zoom  # import here to avoid static TLS ImportError
     sh0, sh1 = np.array(res.shape, dtype=np.float), np.array(res.shape, dtype=np.float)
     sh1[:2] = np.array(data_shape)[:2]
     fac = sh1 / sh0
@@ -1423,6 +1425,7 @@ def __rezoom__(res, data_shape, order=3):
 
 
 def __zm__(data, fac, order=3):
+    from scipy.ndimage import zoom  # import here to avoid static TLS ImportError
     if fac is None:
         return data
     elif np.mean(fac) == 1.0:
