@@ -37,6 +37,7 @@ from tqdm import tqdm
 import os
 import pkgutil
 import platform
+import urllib.request
 
 from py_tools_ds.processing.progress_mon import ProgressBar
 
@@ -164,11 +165,20 @@ class FoGen(object):
             self.fn_table = options["retrieval"]["fn_LUT"]
         else:
             self.path_sicorlib = os.path.dirname(pkgutil.get_loader("sicor").path)
-            if os.path.isfile(os.path.join(self.path_sicorlib, 'AC', 'data', 'EnMAP_LUT_MOD5_formatted_1nm')):
-                self.fn_table = os.path.join(self.path_sicorlib, 'AC', 'data', 'EnMAP_LUT_MOD5_formatted_1nm')
+            self.path_LUT_default = os.path.join(self.path_sicorlib, "AC", "data", "EnMAP_LUT_MOD5_formatted_1nm")
+            if os.path.isfile(self.path_LUT_default):
+                self.fn_table = self.path_LUT_default
             else:
-                raise FileNotFoundError('LUT file was not found. Make sure to indicate path in options file or to'
-                                        'store the LUT at /sicor/AC/data/ directory, otherwise, the AC will not work.')
+                self.logger.info("LUT file was not found locally. Try to download it from Git repository...")
+                self.fname =\
+                    "https://gitext.gfz-potsdam.de/EnMAP/sicor/-/raw/master/sicor/AC/data/EnMAP_LUT_MOD5_formatted_1nm"
+                urllib.request.urlretrieve(self.fname, self.path_LUT_default)
+                if os.path.isfile(self.path_LUT_default):
+                    self.fn_table = self.path_LUT_default
+                else:
+                    raise FileNotFoundError('Download of LUT file failed. Please download it manually from'
+                                            'https://gitext.gfz-potsdam.de/EnMAP/sicor and store it at /sicor/AC/data/'
+                                            'directory. Otherwise, the AC will not work.')
 
         # fn_table = get_data_file(module_name="sicor", file_basename="EnMAP_LUT_MOD5_formatted_1nm")
         luts, axes_x, axes_y, wvl, lut1, lut2, xnodes, nm_nodes, ndim, x_cell = read_lut_enmap_formatted(
@@ -436,11 +446,20 @@ class Fo(object):
             self.fn_table = options["EnMAP"]["Retrieval"]["fn_LUT"]
         else:
             self.path_sicorlib = os.path.dirname(pkgutil.get_loader("sicor").path)
-            if os.path.isfile(os.path.join(self.path_sicorlib, "AC", "data", "EnMAP_LUT_MOD5_formatted_1nm")):
-                self.fn_table = os.path.join(self.path_sicorlib, "AC", "data", "EnMAP_LUT_MOD5_formatted_1nm")
+            self.path_LUT_default = os.path.join(self.path_sicorlib, "AC", "data", "EnMAP_LUT_MOD5_formatted_1nm")
+            if os.path.isfile(self.path_LUT_default):
+                self.fn_table = self.path_LUT_default
             else:
-                raise FileNotFoundError("LUT file was not found. Make sure to indicate path in options file or to "
-                                        "store the LUT at /sicor/AC/data/ directory, otherwise, the AC will not work.")
+                self.logger.info("LUT file was not found locally. Try to download it from Git repository...")
+                self.fname = \
+                    "https://gitext.gfz-potsdam.de/EnMAP/sicor/-/raw/master/sicor/AC/data/EnMAP_LUT_MOD5_formatted_1nm"
+                urllib.request.urlretrieve(self.fname, self.path_LUT_default)
+                if os.path.isfile(self.path_LUT_default):
+                    self.fn_table = self.path_LUT_default
+                else:
+                    raise FileNotFoundError('Download of LUT file failed. Please download it manually from'
+                                            'https://gitext.gfz-potsdam.de/EnMAP/sicor and store it at /sicor/AC/data/'
+                                            'directory. Otherwise, the AC will not work.')
 
         # check if LUT is a regular file (not only an LFS pointer)
         try:
