@@ -24,9 +24,6 @@
 # If not, see <https://www.gnu.org/licenses/>.
 
 
-from scipy.linalg import eigh, norm
-from scipy.spatial import KDTree
-from scipy.stats import linregress
 import numpy as np
 from multiprocessing import Pool
 
@@ -40,8 +37,9 @@ def SLIC_segmentation(data_rad_all, n_pca, segs):
     :param segs:         number of segments
     :return:             flattened radiance data array, number of segments, array of segment labels for each pixel
     """
-    # importing skimage here avoids ImportError: dlopen: cannot load any more object with static TLS
+    # importing skimage and scipy here avoids ImportError: dlopen: cannot load any more object with static TLS
     from skimage.segmentation import slic
+    from scipy.linalg import eigh, norm
 
     # Change from BIP to a long list of spectra
     rows, bands, cols = data_rad_all.shape[0], data_rad_all.shape[2], data_rad_all.shape[1]
@@ -81,6 +79,8 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
     :param processes:    number of CPUs for multiprocessing
     :return:             extrapolated surface reflectance for each pixel
     """
+    from scipy.spatial import KDTree  # import here to avoid static TLS ImportError
+
     # First set up a matrix of locations, one per spectrum in both
     # the reference set and the image cube.  We will simply use
     # row and column indices for simplicity, rather than worrying
@@ -114,6 +114,8 @@ _globs = dict()
 
 
 def _compute_coefficients_for_label(label_idx):
+    from scipy.stats import linregress  # import here to avoid static TLS ImportError
+
     nn = _globs['tree'].query(_globs['locs'][label_idx, :], _globs['k'])[1]
     label_slopes, label_intercepts = zip(*[linregress(x=_globs['rdn'][:, nn, b],
                                                       y=_globs['data'][:, nn, b])[:2]
