@@ -1,12 +1,9 @@
 import numpy as np
-from scipy.interpolate import griddata
-from scipy.ndimage import gaussian_filter
 import warnings
 import logging
 from time import time
 from itertools import product
 from numba import jit
-from scipy.interpolate import bisplrep, bisplev
 
 
 # noinspection PyShadowingNames
@@ -127,6 +124,8 @@ def nanmean_filter(inp, dd):
 
 
 def nangaussian_filter(uu, sigma):
+    from scipy.ndimage import gaussian_filter  # import here to avoid static TLS ImportError
+
     vv = uu.copy()
     vv[uu != uu] = 0
     vv_g = gaussian_filter(vv, sigma=sigma)
@@ -190,6 +189,10 @@ def inpaint(array, sigma=None, logger=None, update_in_place=False, fill_corners=
     :param post_processing: None,"spline","gaussian_filter"
     :return: array filled with meaningful data if update_in_place=False, otherwise None
     """
+    # import here to avoid static TLS ImportError
+    from scipy.interpolate import bisplrep, bisplev
+    from scipy.interpolate import griddata
+    from scipy.ndimage import gaussian_filter
 
     t0 = time()
     logger = logger or logging.getLogger(__name__)
